exceptiontools.MissingMarkError
===============================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError

.. autoclass:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__unicode__
   :noindex:
